@@ -14,8 +14,3 @@ class IAssetCalculationsEngine:
         '''Determine the holdings profit percentage & profit USD, given the holdings.'''
 
         raise NotImplementedError()
-
-    def calculate_holdings_ratios(self, holdings: pd.DataFrame) -> pd.DataFrame:
-        '''Determine the ratios that each asset makes up of the overall portfolio, adding up to 1.'''
-
-        raise NotImplementedError()
